local mod	= DBM:NewMod("Barrens", "DBM-BattlefieldBarrens")
local L		= mod:GetLocalizedStrings()

mod:SetRevision(("$Revision: 13 $"):sub(12, -3))
mod:SetZone(DBM_DISABLE_ZONE_DETECTION)

mod:RegisterEvents(
	"ZONE_CHANGED_NEW_AREA"
)

--Goblin
local warnRocketBoost			= mod:NewSpellAnnounce(142005, 2)
local warnMolotovBarrage		= mod:NewSpellAnnounce(142041, 3)
local warnRocketSwarm			= mod:NewSpellAnnounce(142147, 4)
--Warrior
local warnTitanicThunderclap	= mod:NewSpellAnnounce(142108, 2)
local warnDisruptingBellow		= mod:NewSpellAnnounce(142111, 3)
--Shaman
local warnDarkTwister			= mod:NewSpellAnnounce(142384, 3)
local warnGroundSpike			= mod:NewSpellAnnounce(142481, 3)
local warnCracklingFury			= mod:NewSpellAnnounce(142327, 3)
--Rogue
local warnShadowstep			= mod:NewSpellAnnounce(142171, 3)
local warnVenomBombs			= mod:NewSpellAnnounce(142199, 3)

--General
local specWarnOverturn			= mod:NewSpecialWarning("specWarnOverturn", false)
local specWarnEscort			= mod:NewSpecialWarning("specWarnEscort")
local specWarnCommander			= mod:NewSpecialWarning("specWarnCommander")
--Goblin
local specWarnMolotovBarrage	= mod:NewSpecialWarningMove(142043)
local specWarnRocketSwarm		= mod:NewSpecialWarningSpell(142147, nil, nil, nil, 2)
--Warrior
local specWarnDisruptingBellow	= mod:NewSpecialWarningCast(142111)
--Shaman
local specWarnRuin				= mod:NewSpecialWarningMove(142403)
--Rogue
local specWarnVenomBombs		= mod:NewSpecialWarningMove(142208)

mod:RemoveOption("HealthFrame")
mod:RemoveOption("SpeedKillTimer")

local GetCurrentMapAreaID = GetCurrentMapAreaID
local SetMapToCurrentZone = SetMapToCurrentZone

function mod:ZONE_CHANGED_NEW_AREA()
	if WorldMapFrame:IsVisible() then--World Map is open
		local Z = GetCurrentMapAreaID()
		SetMapToCurrentZone()
		currentZone = GetCurrentMapAreaID()
		if currentZone ~= Z then
			SetMapByID(Z)--Restore old map settings if they differed to what they were prior to forcing mapchange and user has map open.
		end
	else--Map is not open, no reason to go extra miles, just force map to right zone and get right info.
		SetMapToCurrentZone()
		currentZone = GetCurrentMapAreaID()--Get right info after we set map to right place.
	end
	if currentZone == 11 then
		self:RegisterShortTermEvents(
			"CHAT_MSG_MONSTER_EMOTE",
			"CHAT_MSG_MONSTER_YELL",
			"SPELL_AURA_APPLIED",
			"SPELL_CAST_START",
			"SPELL_PERIODIC_DAMAGE"
		)
	else
		self:UnregisterShortTermEvents()
	end
end

function mod:CHAT_MSG_MONSTER_EMOTE(msg)
	if msg == L.Escort or msg:find(L.Escort) then
		specWarnEscort:Show()
	elseif msg == L.Overturn or msg:find(L.Overturn) then
		specWarnOverturn:Show()
	end
end

function mod:CHAT_MSG_MONSTER_YELL(msg, npc)
	if not InCombatLockdown() and self:AntiSpam(30, npc) then--Ignore their yells when we are in combat (probably with one of them). Also anti spam it so when one of them is engaged fighting someone, we don't over trigger alerts about a commander
		specWarnCommander:Show(npc)
	end
end

function mod:SPELL_AURA_APPLIED(args)
	if args.spellId == 142403 and args:IsPlayer() then
		specWarnRuin:Show()
	end
end

function mod:SPELL_CAST_START(args)
	if args.spellId == 142005 then
		warnRocketBoost:Show()
	elseif args.spellId == 142041 then
		warnMolotovBarrage:Show()
	elseif args.spellId == 142147 then
		warnRocketSwarm:Show()
		specWarnRocketSwarm:Show()
	elseif args.spellId == 142108 then
		warnTitanicThunderclap:Show()
	elseif args.spellId == 142111 then
		warnDisruptingBellow:Show()
		specWarnDisruptingBellow:Show()
	elseif args.spellId == 142384 then
		warnDarkTwister:Show()
	elseif args.spellId == 142327 then
		warnCracklingFury:Show()
	elseif args.spellId == 142481 then
		warnGroundSpike:Show()
	elseif args.spellId == 142199 then
		warnVenomBombs:Show()
	end
end

function mod:SPELL_PERIODIC_DAMAGE(_, _, _, _, destGUID, _, _, _, spellId)
	if spellId == 142043 and destGUID == UnitGUID("player") and self:AntiSpam(3, 1) then
		specWarnMolotovBarrage:Show()
	elseif spellId == 142208 and destGUID == UnitGUID("player") and self:AntiSpam(3, 2) then
		specWarnVenomBombs:Show()
	end
end
